==> haskell-tasty-quickcheck-0.11.1-8-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-quickcheck
version:              0.11.1
visibility:           public
id:                   tasty-quickcheck-0.11.1-8Vx4NnVjLFb9L35tkdZLBg
key:                  tasty-quickcheck-0.11.1-8Vx4NnVjLFb9L35tkdZLBg
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/UnkindPartition/tasty
synopsis:             QuickCheck support for the Tasty test framework.
description:          QuickCheck support for the Tasty test framework.

category:             Testing
abi:                  c520c7ae2984bd45f4a7b053fa4135f8
exposed:              True
exposed-modules:      Test.Tasty.QuickCheck
import-dirs:
    /usr/lib/ghc-9.6.7.20250817/site-local/tasty-quickcheck-0.11.1

library-dirs:
    /usr/lib/ghc-9.6.7.20250817/site-local/tasty-quickcheck-0.11.1

library-dirs-static:
    /usr/lib/ghc-9.6.7.20250817/site-local/tasty-quickcheck-0.11.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-quickcheck
hs-libraries:         HStasty-quickcheck-0.11.1-8Vx4NnVjLFb9L35tkdZLBg
depends:
    QuickCheck-2.15.0.1-EwaWMBElPTW2PPUquYLZSL base-4.18.3.0
    optparse-applicative-0.18.1.0-KQP8jsJAas2R1tawxIFsA
    random-1.2.1.3-FQDOWOOVQ4iCxkTbz7wiP5
    tagged-0.8.9-HMh4qZxoofeBZ9IcdInbXO
    tasty-1.5.2-DYWdVUlVmZ2GEsYE1QJgVb

haddock-interfaces:
    /usr/share/doc/haskell-tasty-quickcheck/html/tasty-quickcheck.haddock

haddock-html:         /usr/share/doc/haskell-tasty-quickcheck/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-quickcheck-0.11.1-8.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-quickcheck
version:              0.11.1
visibility:           public
id:                   tasty-quickcheck-0.11.1-12PfOJrYLokIJwGklw71D9
key:                  tasty-quickcheck-0.11.1-12PfOJrYLokIJwGklw71D9
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/UnkindPartition/tasty
synopsis:             QuickCheck support for the Tasty test framework.
description:          QuickCheck support for the Tasty test framework.

category:             Testing
abi:                  f8f7530fe672a3cd1e17bdb786ab9057
exposed:              True
exposed-modules:      Test.Tasty.QuickCheck
import-dirs:
    /usr/lib/ghc-9.6.7.20250817/site-local/tasty-quickcheck-0.11.1

library-dirs:
    /usr/lib/ghc-9.6.7.20250817/site-local/tasty-quickcheck-0.11.1

library-dirs-static:
    /usr/lib/ghc-9.6.7.20250817/site-local/tasty-quickcheck-0.11.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-quickcheck
hs-libraries:         HStasty-quickcheck-0.11.1-12PfOJrYLokIJwGklw71D9
depends:
    QuickCheck-2.15.0.1-EwaWMBElPTW2PPUquYLZSL base-4.18.3.0
    optparse-applicative-0.18.1.0-KQP8jsJAas2R1tawxIFsA
    random-1.2.1.3-FQDOWOOVQ4iCxkTbz7wiP5
    tagged-0.8.9-HMh4qZxoofeBZ9IcdInbXO
    tasty-1.5.2-DYWdVUlVmZ2GEsYE1QJgVb

haddock-interfaces:
    /usr/share/doc/haskell-tasty-quickcheck/html/tasty-quickcheck.haddock

haddock-html:         /usr/share/doc/haskell-tasty-quickcheck/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
